@@ -55,7 +55,11 @@ VkClient::VkClient(QObject* parent)
 
 VkClient::~VkClient()
 {
-    delete vkTransport;
+    if (vkTransport) {
+        vkTransport->vkClose();
+        delete vkTransport;
+        vkTransport = 0;
+    }
 }
 
 QMailMessage::MessageType VkClient::messageType() const
@@ -233,29 +237,28 @@ void VkClient::newConnection()
 // End creating folders
 
     if (!authorized) {
-        if (localSettings.isEmpty())
+        if (localSettings.isEmpty()) {
+            qDebug() << "localSettings is empty, get authParams";
             localSettings = vkCfg.authParams();
+        }
         if (!localSettings.isEmpty()) {
+            qDebug() << "Settings = " << localSettings;
             vkTransport->vkSetSettings(localSettings);
+        } else {
+            qDebug() << "Settings not found, try without";
         }
         vkTransport->vkTestConnection();
-        if (status==UpdateProfile) {
-            emit retrievalCompleted();
-            return;
-        }
-    } else {
-        if (status==UpdateProfile) {
-            emit updateStatus("");
-            emit retrievalCompleted();
-            return;
-        }
     }
-    emit startProcessing();
+    if (authorized) {
+        if (status == UpdateProfile)
+            emit retrievalCompleted();
+        else
+            emit startProcessing();
+    }
 }
 
 void VkClient::connected()
 {
-    authorized=true;
     if (!config.id().isValid()) {
         operationFailed(QMailServiceAction::Status::ErrConfiguration,
                         tr("Cannot send message without account configuration"));
@@ -366,7 +369,7 @@ void VkClient::saveCaptcha(QByteArray code, QByteArray img) {
 }
 
 void VkClient::saveSettings(QByteArray params) {
-
+    authorized=true;
     setLocalSettings(params);
     VkConfigurationEditor vkConfigEditor(&config);
     vkConfigEditor.setAuthParams(params);
@@ -466,8 +469,11 @@ void VkClient::transportError(int status, QString msg)
 */
 void VkClient::closeConnection()
 {
-    if (vkTransport)
+    if (vkTransport) {
         vkTransport->vkClose();
+        delete vkTransport;
+        vkTransport = 0;
+    }
 }
 
 void VkClient::sendNext()
@@ -673,7 +679,7 @@ void VkClient::processResponse(VkResponse* response)
         updateStatus(*(response->text));
         if (response->code == DRV_AUTH_SUCCESS_CODE) {
             qDebug() << "Success connected";
-            emit needSettings();
+            authorized = true;
         } else
         if (response->code == DRV_AUTH_FAILED_CODE) {
             qDebug() << "Broke connected";
@@ -809,9 +815,6 @@ void VkClient::messageProcessed(const QString &uid)
 void VkClient::operationFailed(int code, const QString &text)
 {
     authorized=false;
-    if (vkTransport) {
-        vkTransport->vkClose();
-    }
     qDebug() << "errorOccurred1("<< code << "," << text << ")";
     emit errorOccurred(code, text);
 }
@@ -820,9 +823,6 @@ void VkClient::operationFailed(QMailServiceAction::Status::ErrorCode code,
                                const QString &text)
 {
     authorized=false;
-    if (vkTransport) {
-        vkTransport->vkClose();
-    }
 
     if (status == SendMessage) {
         sendingId = QMailMessageId();
