@@ -63,6 +63,7 @@
 #define VK_MODULE_NAME "/string[@name='moduleName']"
 #define VK_OLD_REQUEST "/string[@name='oldRequest']"
 #define VK_FUNCTION "//Response/@function"
+#define VK_WAS_AUTH "//Response/@authorized"
 #define VK_FROM "//array/@from"
 #define VK_TO "//array/@to"
 #define VK_QUANTITY "//string[@name='quantity']"
@@ -75,7 +76,7 @@ VkTransport::VkTransport(QByteArray name)
     activeRequests(0)
 {
     accountName=QByteArray(name);
-
+    qDebug() << "int vktransport";
 #ifdef VK_LOGING
     vkLog = fopen(QDir::tempPath().append(QDir::separator()).toAscii().append(VK_LOGING_FILE),"w");
 #endif
@@ -115,6 +116,8 @@ VkTransport::VkTransport(QByteArray name)
     decoder =  QTextCodec::codecForName("utf8");
     totalInboxCount=0;
     totalOutboxCount=0;
+
+    //connect(this, SIGNAL(vkGetRequest(QByteArray)), this, SLOT(vkSendRequest(QByteArray)),Qt::QueuedConnection);
 }
 
 VkTransport::~VkTransport()
@@ -366,7 +369,7 @@ void VkTransport::vkGetSettings()
 void VkTransport::vkTestConnection()
 {
     // Debug message for calling function
-    qDebug() << __FILE__<<":"<< __LINE__<<": Call vkSetSettings()";
+    qDebug() << __FILE__<<":"<< __LINE__<<": Call vkTestConnection()";
 
     QString reqStr = QString("<?xml version='1.0'?>")
               + QString("<TransitData id='1' type='data'>")
@@ -522,6 +525,7 @@ void VkTransport::vkGetNewInbox()
 void VkTransport::vkSendRequest(QByteArray xmlRequest)
 {
     if (needShutdown) {
+        qDebug() << "Process aborted by needShutdown";
         return;
     } else
         ++activeRequests;
@@ -571,6 +575,13 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
         qDebug() << "functionName not found" << endl;
         return;
     }
+    char *authorized;
+    if ((authorized = parseString(VK_WAS_AUTH, respContext, false)) != 0 && strcmp(authorized,"true") == 0) {
+        qDebug() << "Was athentification";
+        vkGetSettings();
+        delete [] authorized;
+    }
+
     qDebug() << "Processing " << functionName << endl;
 
     xmlNodePtr node = NULL;
@@ -864,19 +875,9 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
                 }
                 if (!recipientId.isEmpty())
                     recipientId.append(vkFakeAdress);
-  //              qDebug() << "recipientId=" << recipientId  << " senderId=" << senderId;
                 if (canIgnoreSender && recipientId==senderId && !recipientId.isEmpty() && recipients > 1 ) {
-//                    qDebug() << "Filtred!!!";
                     continue;
                 }
-/*                else {
-                    qDebug() << "Added!!!";
-                    qDebug() << (canIgnoreSender ? "canIgnoreSender":"!canIgnoreSender");
-                    qDebug() << (recipientId.isEmpty() ? "recipientId.isEmpty()" : "!recipientId.isEmpty()");
-                    qDebug() <<  (rec > 1 ? "rec > 1" : "!(rec > 1)") << "rec=" << rec;
-                    qDebug() <<  (recipientId==senderId ? "recipientId==senderId" : "!(recipientId==senderId)");
-                }
-*/
                 // RecipientName
                 recipientName.clear();
                 xpathRequestBufferPointer = stpcpy (xpathRequestBufferCurrentPointer, (QByteArray(VK_RECIPIENT_PREFIX)+"["+recChar+"]"+QByteArray(VK_RECIPIENT_NAME)).data());
@@ -911,11 +912,11 @@ void VkTransport::vkSendRequest(QByteArray xmlRequest)
                                             QMailMessageBodyFwd::NoEncoding,
                                             QMailMessageBodyFwd::AlreadyEncoded
                                         ));
-                messageBody = message->body().data();
-                qDebug() << "Text:" << messageBody << endl;
+                messageBody = decoder->toUnicode(parsedString); //message->body().data();
+                //qDebug() << "Text:" << messageBody << endl;
                 delete [] parsedString;
             } else {
-                message->setBody(QMailMessageBody::fromData ("Empty message body.",
+                message->setBody(QMailMessageBody::fromData ("Empty message.",
                                             QMailMessageContentType("text/plain; charset=UTF-8"),
                                             QMailMessageBodyFwd::NoEncoding // working with 7&8 bit
                                         ));
